<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="140px"
      v-loading="formLoading"
    >
      <el-form-item label="检查类型名" prop="name">
        <el-input v-model="formData.name" placeholder="请输入检查类型名" />
      </el-form-item>
      <el-form-item label="检查类型值" prop="value">
        <el-input v-model="formData.value" placeholder="请输入检查类型值" />
      </el-form-item>
      <el-form-item label="允许准备中人数" prop="readyNum">
        <el-input v-model="formData.readyNum" placeholder="请输入允许准备中人数" />
      </el-form-item>
      <el-form-item label="需要设备领用" prop="needDevReady">
        <el-switch
            v-model="formData.needDevReady"
            :active-value="1"
            :inactive-value="0"
        />
      </el-form-item>
      <el-form-item label="叫号列" prop="callingColumn">
        <el-input v-model="formData.callingColumn" placeholder="请输入叫号列" />
      </el-form-item>
      <el-form-item label="显示患者条码" prop="displayBarcode">
        <el-checkbox-group v-model="formData.displayBarcode">
          <el-checkbox
              v-for="(dict, index) in getIntDictOptions(DICT_TYPE.ECG_PAT_SOURCE)"
              :key="index"
              :label="dict.label"
              :value=dict.value
          />
        </el-checkbox-group>
      </el-form-item>
      <el-form-item label="需要确费" prop="expenseRecognition">
        <el-switch
            v-model="formData.expenseRecognition"
            :active-value="1"
            :inactive-value="0"
        />
      </el-form-item>
      <el-form-item label="时段预约规定人数" prop="timeslotBookNum">
        <el-input v-model="formData.timeslotBookNum" placeholder="请输入时段预约规定人数" />
      </el-form-item>
      <el-form-item label="每时段预留人数" prop="timeslotReservedNum">
        <el-input v-model="formData.timeslotReservedNum" placeholder="请输入每时段预留人数" />
      </el-form-item>
      <el-form-item label="预约注意事项" prop="notes">
        <el-input v-model="formData.notes" placeholder="请输入预约注意事项" />
      </el-form-item>
      <el-form-item label="序号前缀" prop="notes">
        <el-input v-model="formData.seqPrefix" placeholder="请输入序号前缀" />
      </el-form-item>
      <el-form-item label="亲和的检查类型" prop="affinityCheckTypes">
        <el-checkbox-group v-model="formData.affinityCheckTypes">
          <el-checkbox v-for="checkTypeVO in checkTypeStore.getCheckTypeOptions()" :value="checkTypeVO.value" :key="checkTypeVO.value">{{checkTypeVO.label}}</el-checkbox>
        </el-checkbox-group>
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { CheckTypeApi, CheckTypeVO } from '@/api/ecg/checktype'
import {useCheckTypeStore} from "@/store/modules/checkType";
import {DICT_TYPE, getIntDictOptions} from "@/utils/dict";

/** 检查类型 表单 */
defineOptions({ name: 'CheckTypeForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const checkTypeStore = useCheckTypeStore();

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  name: undefined,
  value: undefined,
  readyNum: undefined,
  needDevReady: undefined,
  callingColumn: undefined,
  displayBarcode: [],
  expenseRecognition: undefined,
  timeslotBookNum: undefined,
  timeslotReservedNum: undefined,
  affinityCheckTypes: [],
  notes: undefined,
  seqPrefix: undefined
})
const formRules = reactive({
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await CheckTypeApi.getCheckType(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as CheckTypeVO
    if (formType.value === 'create') {
      await CheckTypeApi.createCheckType(data)
      message.success(t('common.createSuccess'))
    } else {
      await CheckTypeApi.updateCheckType(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    name: undefined,
    value: undefined,
    readyNum: undefined,
    needDevReady: undefined,
    callingColumn: undefined,
    displayBarcode: [],
    expenseRecognition: undefined,
    timeslotBookNum: undefined,
    timeslotReservedNum: undefined,
    affinityCheckTypes: [],
    notes: undefined,
    seqPrefix: undefined
  }
  formRef.value?.resetFields()
}
</script>